@@ -6,9 +6,9 @@ __author__ = "Christian Heider Nielsen"
 __doc__ = r"""
 """
 
-import pathlib
+from pathlib import Path
 
-with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
 
 try:
@@ -17,7 +17,5 @@ try:
     from draugr.drawers.mpl_drawers.series_scroll_plot import *
     from draugr.drawers.mpl_drawers.spectral import *
 except ImportError as ix:
-    print(
-        f"Make sure requirements is installed for {pathlib.Path(__file__).parent.name}"
-    )
+    print(f"Make sure requirements is installed for {Path(__file__).parent.name}")
     raise ix
