@@ -9,12 +9,11 @@ __doc__ = r"""
 
 __all__ = []
 
-from draugr.gtk_utilities import GtkThemePreferences
+from draugr.os_utilities.linux_utilities import GtkThemePreferences
 
 
 def main():
-    """
-  """
+    """ """
     with GtkThemePreferences() as a:
         a.prefer_dark_mode = not a.prefer_dark_mode
 
