@@ -30,17 +30,15 @@ def mix_ratio(
     log_multiplier: int = LOG_MAGNITUDE_MULTIPLIER,
 ) -> Sequence:
     """
-# Function to mix clean speech and noise at various SNR levels
+    # Function to mix clean speech and noise at various SNR levels
 
-# Normalizing to -25 dB FS
+    # Normalizing to -25 dB FS
 
-:param s1:
-:param s2:
-:param db_ratio:
-:param norm_db:
-:param log_multiplier:
-:return:
-"""
+    :param s1:
+    :param s2:
+    :param db_ratio:
+    :param log_multiplier:
+    :return:"""
     s1, s2 = min_length_truncate_batch((s1, s2))
     s1_max = numpy.abs(s1).max()
     mix = (s1 / s1_max) + (
@@ -52,8 +50,7 @@ def mix_ratio(
 if __name__ == "__main__":
 
     def asad():
-        """
-"""
+        """ """
         from neodroidaudition.data.recognition.libri_speech import LibriSpeech
         from neodroidaudition.noise_generation.gaussian_noise import white_noise
 
@@ -69,8 +66,7 @@ if __name__ == "__main__":
         print(mixed)
 
     def asadsa():
-        """
-"""
+        """ """
         from draugr.torch_utilities import to_tensor
         from neodroidaudition.data.recognition.libri_speech import LibriSpeech
         from neodroidaudition.noise_generation.gaussian_noise import white_noise
@@ -105,8 +101,7 @@ if __name__ == "__main__":
             )
 
     def asadsa2():
-        """
-"""
+        """ """
         from draugr.torch_utilities import to_tensor
         from neodroidaudition.data.recognition.libri_speech import LibriSpeech
         from neodroidaudition.noise_generation.gaussian_noise import white_noise
