@@ -20,14 +20,12 @@ from draugr.numpy_utilities.signal_utilities.signal_statistics import mean_squar
 
 
 def normalise_signal_minmax(signal: numpy.ndarray) -> numpy.ndarray:
-    """
-  """
+    """ """
     return numpy.interp(signal, (signal.min(), signal.max()), (-1, 1))
 
 
 def normalise_signal_max_abs(signal: numpy.ndarray) -> numpy.ndarray:
-    """
-  """
+    """ """
     return signal / numpy.abs(signal).max()
 
 
@@ -35,9 +33,8 @@ def normalise_signal(
     signal: numpy.ndarray, variance: numpy.ndarray = None
 ) -> numpy.ndarray:
     """Normalise power in y to a (standard normal) white noise signal.
-  Optionally normalise to power in signal `x`.
-  The mean power of a Gaussian with `mu=0` and `sigma=1` is 1.
-  """
+    Optionally normalise to power in signal `x`.
+    The mean power of a Gaussian with `mu=0` and `sigma=1` is 1."""
     if variance is not None:
         variance = mean_square(variance)
     else:
@@ -49,16 +46,14 @@ def normalise_signal(
 def heaviside(signal: numpy.ndarray) -> numpy.ndarray:
     """Heaviside.
 
-  Returns the value 0 for `x < 0`, 1 for `x > 0`, and 1/2 for `x = 0`.
-  """
+    Returns the value 0 for `x < 0`, 1 for `x > 0`, and 1/2 for `x = 0`."""
     return 0.5 * (numpy.sign(signal) + 1)
 
 
 if __name__ == "__main__":
 
     def asiudha():
-        """
-    """
+        """ """
         a = numpy.random.random(9) - 0.5
         print(
             normalise_signal_minmax(a),
