@@ -7,6 +7,11 @@ __doc__ = r"""
            Created on 25/03/2020
            """
 
+from pathlib import Path
+
+with open(Path(__file__).parent / "README.md", "r") as this_init_file:
+    __doc__ += this_init_file.read()
+
 from .boxes_2d import *
 from .colors import *
 from .draw_boxes import *
