@@ -21,8 +21,6 @@ from .replication import *
 from .sockets import *
 from .styling import *
 from .torch_like_channel_transformation import *
-from .resource_utilities import *
-from .platform_selection import *
 from .strings import *
 from .powers import *
 from .contexts import *
