@@ -14,8 +14,8 @@ __all__ = ["fan_in_init", "xavier_init", "constant_init", "normal_init"]
 def fan_in_init(model: Module):
     """
 
-  :param model:
-  :type model:"""
+    :param model:
+    :type model:"""
     for m in model.modules():
         if isinstance(m, (Conv2d, Linear)):
             fan_in = m.weight.size(1)
@@ -27,10 +27,10 @@ def fan_in_init(model: Module):
 def xavier_init(model: Module, activation="relu"):
     """
 
-  :param model:
-  :type model:
-  :param activation:
-  :type activation:"""
+    :param model:
+    :type model:
+    :param activation:
+    :type activation:"""
     gain = calculate_gain(activation)
     for m in model.modules():
         if isinstance(m, (Conv2d, Linear)):
@@ -41,10 +41,10 @@ def xavier_init(model: Module, activation="relu"):
 def constant_init(model: Module, constant: float = 1):
     """
 
-  :param model:
-  :type model:
-  :param constant:
-  :type constant:"""
+    :param model:
+    :type model:
+    :param constant:
+    :type constant:"""
     for m in model.modules():
         if isinstance(m, (Conv2d, Linear)):
             constant_(m.weight, constant)
@@ -54,10 +54,11 @@ def constant_init(model: Module, constant: float = 1):
 def normal_init(model: Module, mean: float = 0, std: float = 1.0):
     """
 
-  :param model:
-  :type model:
-  :param constant:
-  :type constant:"""
+      :param mean:
+      :param std:
+    :param model:
+    :type model:
+    :type constant:"""
     for m in model.modules():
         if isinstance(m, (Conv2d, Linear)):
             torch.nn.init.normal_(m.weight, mean, std)
