@@ -18,16 +18,14 @@ def global_torch_dtype(
 ) -> torch.dtype:
     """
 
-  first time call stores to dtype for global reference, later call must manually override
+    first time call stores to dtype for global reference, later call must manually override
 
-  :param verbose:
-  :type verbose:
-  :param cuda_if_available:
-  :type cuda_if_available:
-  :param override:
-  :type override:
-  :return:
-  :rtype:"""
+    :param verbose:
+    :type verbose:
+    :param override:
+    :type override:
+    :return:
+    :rtype:"""
     global GLOBAL_DTYPE
 
     if override is not None:
@@ -42,8 +40,7 @@ def global_torch_dtype(
 
 
 def set_global_torch_dtype(dtype: torch.dtype) -> None:
-    """
-  """
+    """ """
     global GLOBAL_DTYPE
     GLOBAL_DTYPE = dtype
     torch.set_default_dtype(GLOBAL_DTYPE)
@@ -52,8 +49,7 @@ def set_global_torch_dtype(dtype: torch.dtype) -> None:
 if __name__ == "__main__":
 
     def stest_override():
-        """
-    """
+        """ """
         print(global_torch_dtype(verbose=True))
         print(global_torch_dtype(override=torch.double, verbose=True))
         print(global_torch_dtype(verbose=True))
