@@ -14,25 +14,24 @@ __all__ = ["plot_gradients_3d"]
 
 
 def plot_gradients_3d() -> pyplot.Figure:
-    """
-  """
+    """ """
     fig = pyplot.figure()
     ax = fig.gca(projection="3d")
-    X = numpy.arange(-5, 5, 0.25)
-    Y = numpy.arange(-5, 5, 0.25)
-    X, Y = numpy.meshgrid(X, Y)
-    R = numpy.sqrt(X ** 2 + Y ** 2)
-    Z = numpy.sin(R)
-    Gx, Gy = numpy.gradient(Z)  # gradients with respect to x and y
-    G = (Gx ** 2 + Gy ** 2) ** 0.5  # gradient magnitude
-    N = G / G.max()  # normalize 0..1
-    surf = ax.plot_surface(
-        X,
-        Y,
-        Z,
+    x = numpy.arange(-5, 5, 0.25)
+    y = numpy.arange(-5, 5, 0.25)
+    x, y = numpy.meshgrid(x, y)
+    r = numpy.sqrt(x ** 2 + y ** 2)
+    z = numpy.sin(r)
+    gx, gy = numpy.gradient(z)  # gradients with respect to x and y
+    g = (gx ** 2 + gy ** 2) ** 0.5  # gradient magnitude
+    n = g / g.max()  # normalize 0..1
+    ax.plot_surface(
+        x,
+        y,
+        z,
         rstride=1,
         cstride=1,
-        facecolors=cm.jet(N),
+        facecolors=cm.jet(n),
         linewidth=0,
         antialiased=False,
         shade=False,
