@@ -13,10 +13,10 @@ import numpy
 from matplotlib import pyplot
 from scipy.signal import spectrogram, welch
 
-from draugr.python_utilities.powers import next_pow_2
-from warg import Number
+from draugr.python_utilities import next_pow_2
+from warg import Number, drop_unused_kws, passes_kws_to
 
-__all__ = ["spectral_plot", "ltass_plot", "spectrum_plot", "fft_plot"]
+__all__ = ["spectral_plot", "ltas_plot", "spectrum_plot", "fft_plot"]
 
 
 def spectral_plot(
@@ -26,8 +26,7 @@ def spectral_plot(
     fig_size: Sequence = (4.8, 2.4),
 ) -> pyplot.Figure:
     """
-  return new figure
-  """
+    return new figure"""
     assert fxt.shape == (*frequencies.shape, *time.shape)
     f, ax = pyplot.subplots(figsize=fig_size)
     ax.pcolormesh(time, frequencies / 1000, 10 * numpy.log10(fxt), cmap="viridis")
@@ -36,8 +35,19 @@ def spectral_plot(
     return f
 
 
-def ltass_plot(signal: Sequence, sampling_rate: int, label: str = "#") -> pyplot.Figure:
-    """"""
+@drop_unused_kws
+@passes_kws_to(pyplot.semilogy)
+def ltas_plot(
+    signal: Sequence, sampling_rate: int, label: str = "#", **kwargs
+) -> pyplot.Figure:
+    """
+    Long-term average spectrum
+
+    :param signal:
+    :param sampling_rate:
+    :param label:
+    :return:
+    """
     n_per_seg = next_pow_2(
         sampling_rate * (20 / 1000)
     )  # 20 ms, next_pow_2 per seg == n_fft
@@ -45,16 +55,22 @@ def ltass_plot(signal: Sequence, sampling_rate: int, label: str = "#") -> pyplot
     f, spectrum = welch(
         signal, sampling_rate, window="hanning", nperseg=n_per_seg, scaling="spectrum"
     )  # Average Power spectrum of signal.
-    pyplot.semilogy(f, numpy.sqrt(spectrum), label=label)
+    pyplot.semilogy(f, numpy.sqrt(spectrum), label=label, **kwargs)
     pyplot.xlabel("frequency [Hz]")
-    pyplot.ylabel("Linear spectrum [V RMS]")
+    pyplot.ylabel("Amplitude")
     return pyplot.gcf()
 
 
 def spectrum_plot(
     signal: Sequence, sampling_rate: int, window_length_ms: Number = (20 / 1000)
 ) -> pyplot.Figure:
-    """"""
+    """
+
+    :param signal:
+    :param sampling_rate:
+    :param window_length_ms:
+    :return:
+    """
     n_per_seg = next_pow_2(
         sampling_rate * window_length_ms
     )  # 20 ms, next_pow_2 per seg == n_fft
@@ -70,7 +86,7 @@ def spectrum_plot(
 
 
 def fft_plot(signal: Sequence, *, line_width: float = 0.2) -> pyplot.Figure:
-    """"""
+    """ """
     n_per_seg = next_pow_2(len(signal))
     spectrum = numpy.fft.fft(signal, n_per_seg)[: n_per_seg // 2]
     frequencies = numpy.fft.fftfreq(n_per_seg)[: n_per_seg // 2]
@@ -83,9 +99,8 @@ def fft_plot(signal: Sequence, *, line_width: float = 0.2) -> pyplot.Figure:
 
 if __name__ == "__main__":
 
-    def asdijaisd():
-        """
-    """
+    def main():
+        """ """
         sr = 1000
         t = numpy.arange(sr * 4) / sr
         # noise = numpy.random.rand(sr * 2) * 0.001
@@ -97,7 +112,7 @@ if __name__ == "__main__":
         spectrum_plot(signal, sr)
         pyplot.show()
 
-        ltass_plot(signal, sr)
+        ltas_plot(signal, sr)
         pyplot.show()
 
-    asdijaisd()
+    main()
