@@ -29,7 +29,7 @@ __all__ = ["TerminalPlotWriter"]
 
 
 class TerminalPlotWriter(Writer, ImageWriterMixin):
-    """"""
+    """ """
 
     def image(
         self,
@@ -40,8 +40,7 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
         dataformats: str = "NCHW",
         **kwargs,
     ) -> None:
-        """
-    """
+        """ """
         self.E.write(terminalise_image(render_image(data, scale=(28, 28))))
 
     def _open(self):
@@ -60,7 +59,8 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
     def stats(self, value: MetricCollection, step_i: int = None):
         """
 
-    :type value: object"""
+            :param step_i:
+        :type value: object"""
         if step_i:
             if self.filter(self._stats_tag):
                 self._stats(value, self._counter[self._stats_tag])
@@ -88,21 +88,20 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
 
 
 if __name__ == "__main__":
-
     with TerminalPlotWriter() as w:
         w.scalar("What", 4)
         w.image("bro", numpy.random.randint(0, 255, (28, 28, 3)), 0)
 
     '''
 def train_episodically_old(self,
-         env,
-         test_env,
-         *,
-         rollouts=2000,
-         render=False,
-         render_frequency=100,
-         stat_frequency=10,
-         ):
+ env,
+ test_env,
+ *,
+ rollouts=2000,
+ render=False,
+ render_frequency=100,
+ stat_frequency=10,
+ ):
 
 E = range(1, rollouts)
 E = tqdm(E, f"Episode: {1}", leave=False, disable=not render)
@@ -139,14 +138,14 @@ return NOD(model=self._distribution_parameter_regressor, stats=stats)
 
 
 def train_episodically_old(self,
-         _environment,
-         *,
-         rollouts=10000,
-         render=False,
-         render_frequency=100,
-         stat_frequency=100,
-         **kwargs,
-         ):
+ _environment,
+ *,
+ rollouts=10000,
+ render=False,
+ render_frequency=100,
+ stat_frequency=100,
+ **kwargs,
+ ):
 """
 :param _environment:
 :type _environment:,0
