@@ -7,39 +7,48 @@ __doc__ = r"""
            Created on 28-03-2021
            """
 
-import numpy
 import torch
 
 from draugr import PROJECT_APP_PATH
 from draugr.torch_utilities import (
     TensorBoardPytorchWriter,
-    float_nchw_to_nhwc_uint_batch,
-    to_tensor,
-)
-from draugr.torch_utilities.tensors.dimension_order import (
-    hwc_to_chw_tensor,
-    nchw_to_nhwc_tensor,
-    nhwc_to_nchw_tensor,
 )
 
 if __name__ == "__main__":
 
     def main():
         """
-    TODO:!!!!
-"""
+        TODO:!!!!"""
 
         with TensorBoardPytorchWriter(
             PROJECT_APP_PATH.user_log / "Tests" / "Writers"
         ) as writer:
             vertices_tensor = torch.as_tensor(
-                [[1, 1, 1], [-1, -1, 1], [1, -1, -1], [-1, 1, -1],], dtype=torch.float
+                [
+                    [1, 1, 1],
+                    [-1, -1, 1],
+                    [1, -1, -1],
+                    [-1, 1, -1],
+                ],
+                dtype=torch.float,
             ).unsqueeze(0)
             colors_tensor = torch.as_tensor(
-                [[255, 0, 0], [0, 255, 0], [0, 0, 255], [255, 0, 255],], dtype=torch.int
+                [
+                    [255, 0, 0],
+                    [0, 255, 0],
+                    [0, 0, 255],
+                    [255, 0, 255],
+                ],
+                dtype=torch.int,
             ).unsqueeze(0)
             faces_tensor = torch.as_tensor(
-                [[0, 2, 3], [0, 3, 1], [0, 1, 2], [1, 3, 2],], dtype=torch.int
+                [
+                    [0, 2, 3],
+                    [0, 3, 1],
+                    [0, 1, 2],
+                    [1, 3, 2],
+                ],
+                dtype=torch.int,
             ).unsqueeze(0)
 
             writer.mesh(
